@@ -8,7 +8,9 @@
 
   # Inform user if DNAcopy is missing
   if (isPackageInstalled("DNAcopy")) {
-    library("DNAcopy");
+    # To please/trick R CMD check
+    loadPackage <- base::library;
+    loadPackage("DNAcopy");
   } else {
     msg <- "The Bioconductor package 'DNAcopy' is not installed. Please see http://www.bioconductor.org/ on how to install it, or try calling installDNAcopy().";
     hrule <- paste(rep("*", times=getOption("width", 80L)-1L), collapse="");
